=====================
Getting data for RIFT
=====================

RIFT can be run on any LIGO or LIGO-like data. It uses frames containing noise and signals to ...

One can use real LIGO data to run real event analyses. The data can be obtained from ...

Another possibility is to create fake data with injected gravitational wave signals. This is particularly useful for performing studies on waveform systematics, checking code changes, ... Fake data can be created using ...















			















			  
